Package: scales
Title: Scale Functions for Visualization
Version: 1.4.0
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@posit.co", role = "aut"),
    person("Thomas Lin", "Pedersen", , "thomas.pedersen@posit.co", role = c("cre", "aut"),
           comment = c(ORCID = "0000-0002-5147-4711")),
    person("Dana", "Seidel", role = "aut"),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Graphical scales map data to aesthetics, and provide methods
    for automatically determining breaks and labels for axes and legends.
License: MIT + file LICENSE
URL: https://scales.r-lib.org, https://github.com/r-lib/scales
BugReports: https://github.com/r-lib/scales/issues
Depends: R (>= 4.1)
Imports: cli, farver (>= 2.0.3), glue, labeling, lifecycle, R6,
        RColorBrewer, rlang (>= 1.1.0), viridisLite
Suggests: bit64, covr, dichromat, ggplot2, hms (>= 0.5.0), stringi,
        testthat (>= 3.0.0)
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Config/usethis/last-upkeep: 2025-04-23
Encoding: UTF-8
LazyLoad: yes
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-04-23 18:27:04 UTC; thomas
Author: Hadley Wickham [aut],
  Thomas Lin Pedersen [cre, aut]
    (<https://orcid.org/0000-0002-5147-4711>),
  Dana Seidel [aut],
  Posit Software, PBC [cph, fnd] (03wc8by49)
Maintainer: Thomas Lin Pedersen <thomas.pedersen@posit.co>
Repository: CRAN
Date/Publication: 2025-04-24 11:00:02 UTC
Built: R 4.4.0; ; 2026-07-18 02:06:55 UTC; unix
