# This file was generated by Rcpp::compileAttributes
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

doColorRamp <- function(colors, x, alpha, naColor) {
    .Call('scales_doColorRamp', PACKAGE = 'scales', colors, x, alpha, naColor)
}

rgbToLab <- function(rgb) {
    .Call('scales_rgbToLab', PACKAGE = 'scales', rgb)
}

rgbToXyz <- function(rgb) {
    .Call('scales_rgbToXyz', PACKAGE = 'scales', rgb)
}

