% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/pal-identity.r
\name{identity_pal}
\alias{identity_pal}
\title{Identity palette.}
\usage{
identity_pal()
}
\description{
Leaves values unchanged - useful when the data is already scaled.
}

