% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/pal-linetype.r
\name{linetype_pal}
\alias{linetype_pal}
\title{Line type palette (discrete).}
\usage{
linetype_pal()
}
\description{
Based on a set supplied by Richard Pearson, University of Manchester
}

