% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/pal-gradient.r
\name{seq_gradient_pal}
\alias{seq_gradient_pal}
\title{Sequential colour gradient palette (continous).}
\usage{
seq_gradient_pal(low = mnsl("10B 4/6"), high = mnsl("10R 4/6"),
  space = "Lab")
}
\arguments{
\item{low}{colour for low end of gradient.}

\item{high}{colour for high end of gradient.}

\item{space}{colour space in which to calculate gradient. Must be "Lab" -
other values are deprecated.}
}
\description{
Sequential colour gradient palette (continous).
}
\examples{
x <- seq(0, 1, length.out = 25)
show_col(seq_gradient_pal()(x))
show_col(seq_gradient_pal("white", "black")(x))

library(munsell)
show_col(seq_gradient_pal("white", mnsl("10R 4/6"))(x))
}

