% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/trans.r
\name{as.trans}
\alias{as.trans}
\title{Convert character string to transformer.}
\usage{
as.trans(x)
}
\arguments{
\item{x}{name of transformer}
}
\description{
Convert character string to transformer.
}

