% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/trans-numeric.r
\name{reciprocal_trans}
\alias{reciprocal_trans}
\title{Reciprocal transformation.}
\usage{
reciprocal_trans()
}
\description{
Reciprocal transformation.
}

