% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/trans-numeric.r
\name{reverse_trans}
\alias{reverse_trans}
\title{Reverse transformation.}
\usage{
reverse_trans()
}
\description{
Reverse transformation.
}

