% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/trans-numeric.r
\name{asn_trans}
\alias{asn_trans}
\title{Arc-sin square root transformation.}
\usage{
asn_trans()
}
\description{
Arc-sin square root transformation.
}

