% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/trans-numeric.r
\name{identity_trans}
\alias{identity_trans}
\title{Identity transformation (do nothing).}
\usage{
identity_trans()
}
\description{
Identity transformation (do nothing).
}

