% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/pal-shape.r
\name{shape_pal}
\alias{shape_pal}
\title{Shape palette (discrete).}
\usage{
shape_pal(solid = TRUE)
}
\arguments{
\item{solid}{should shapes be solid or not?}
}
\description{
Shape palette (discrete).
}

