% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/scales.r
\docType{package}
\name{package-scales}
\alias{package-scales}
\alias{package-scales-package}
\alias{scales}
\title{Generic plot scaling methods}
\description{
Generic plot scaling methods
}

