% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/trans-numeric.r
\name{atanh_trans}
\alias{atanh_trans}
\title{Arc-tangent transformation.}
\usage{
atanh_trans()
}
\description{
Arc-tangent transformation.
}

