% Generated by roxygen2 (4.1.1): do not edit by hand
% Please edit documentation in R/trans-numeric.r
\name{sqrt_trans}
\alias{sqrt_trans}
\title{Square-root transformation.}
\usage{
sqrt_trans()
}
\description{
Square-root transformation.
}

